services

package
v0.4.12 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 24, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Service

type Service interface {
	Name() string
	Detect(r *http.Request) bool
	ServeHTTP(w http.ResponseWriter, r *http.Request)
}

Directories

Path Synopsis
Package acm emulates the AWS Certificate Manager (ACM) control plane.
Package acm emulates the AWS Certificate Manager (ACM) control plane.
Package alb emulates the AWS ELBv2 (ALB) control plane.
Package alb emulates the AWS ELBv2 (ALB) control plane.
Package apigateway emulates the AWS API Gateway REST API management plane and the execute-api runtime.
Package apigateway emulates the AWS API Gateway REST API management plane and the execute-api runtime.
Package cloudfront emulates the AWS CloudFront distribution control plane.
Package cloudfront emulates the AWS CloudFront distribution control plane.
Package cloudwatchmetrics emulates the AWS CloudWatch Metrics API.
Package cloudwatchmetrics emulates the AWS CloudWatch Metrics API.
Package ecr emulates the AWS Elastic Container Registry management plane and the Docker V2 registry protocol for local development.
Package ecr emulates the AWS Elastic Container Registry management plane and the Docker V2 registry protocol for local development.
Package ecs emulates the AWS Elastic Container Service (ECS) control plane for local development.
Package ecs emulates the AWS Elastic Container Service (ECS) control plane for local development.
Package elasticache emulates the AWS ElastiCache control plane.
Package elasticache emulates the AWS ElastiCache control plane.
Package rds emulates the AWS RDS/Aurora control plane.
Package rds emulates the AWS RDS/Aurora control plane.
Package route53 emulates the AWS Route 53 control plane.
Package route53 emulates the AWS Route 53 control plane.
Package s3control emulates the AWS S3 Control management plane.
Package s3control emulates the AWS S3 Control management plane.

Jump to